// ServerAppTestTask.execute()

// Startup/Initialize the servers
foreach (ServerElement element in this.servers) {
	Server server = element.GetServerInstance();	
	if (element.StartServer)
		server.StartUp();
}

// Note, if any of the servers fails to start (ServerException is caught),
// the servers that were started should be stopped
// The order of stopping the servers is reverse
// to that one of starting the servers
// All the exception caught while processing should be wrapped in ServerTaskException
// Note, that the complete list of caught exceptions should be supplied


// Startup/Initialize the servers
foreach (ServerElement element in this.servers) {
	Server server = element.GetServerInstance();	
	if (element.InitServer)
		server.InitData();
}
// Note, if any of the servers fails to initialize (ServerException is caught),
// the servers that were started should be stopped,
// the servers that were initialized should be dinitialized
// The order of stopping/deinitializing the servers is reverse
// to that one of starting/initializing the servers
// All the exception caught while processing should be wrapped in ServerTaskException
// Note, that the complete list of caught exceptions should be supplied



// Run the tests, just class the method of superclass
super.ExecuteTask();

// Deinitialize/shutdown the servers
for (int i = this.servers.GetLength() - 1; i >= 0; --i) {
	Server server = this.servers[i].GetServerInstance();	
	if (this.servers[i].InitServer)
		server.CleanUpData();
	if (this.servers[i].StartServer)
		server.ShutDown();
}

// Note, if any of the servers fails to deinitialize/stop (ServerException is caught),
// the servers the remaining servers should be stopped, but the exception will be thrown.
// All the exception caught while processing should be wrapped in ServerTaskException
// Note, that the complete list of caught exceptions should be supplied



//////////////////////////////////////
// Deploy an application

// Create a NAnt copy task
CopyTask copyTask = new CopyTask();
// Specify destination directory
copyTask.ToDirectory(Options[DEPLOYMENT_DIR]);
// Specify files to copy
copyTask.CopyfileSet = SourceFiles;
// Specify, that files should be overwritten
copyTask.Overwrite = true;
// Execute a task
copyTask.ExecuteTask();



//////////////////////////////////
// Start the server

string serviceName;

// Get the server service name
if (Options[SERVICE_NAME] == null, or  empty string) {
	serviceName = DEFAULT_SERVICE_NAME;	
} else {
	serviceName = Options[SERVICE_NAME];
}

// Create an appropriate ServiceController
ServiceController serviceController = new ServiceController(serviceName);

// Get timeout
int timeout;
if (Options[TIMEOUT] == null, or  empty string) {
	timeout = DEFAULT_TIMEOUT;
} else {
	timeout = Int32.Parse(Options[TIMEOUT]);
}

// Check if the service was is running
if (serviceController.Status == ServiceContollerStatus.Running) {
	// If it is running, the ServerException should be thrown
	// If the server should not be started,
        // the "startserver" attribute of the corresponding XML element should be "false"
}


// Start the service
if (serviceController.Status == ServiceContollerStatus.Paused) {
	ServiceController.Continue();
} else {
	ServiceController.Start();
}

// Wait for the service to reach the desired status, or the timeout expired
service.WaitForStatus(ServiceControllerStatus.Running, TimeSpan.ForMilliseconds(timeout));
// Note, that the TimeoutException should be caught and wrapped into the ServerException
                                                                               	


//////////////////////////////////
// Stop the server

// Allmost analogous to the start server algorithm

string serviceName;

// Get the server service name
if (Options[SERVICE_NAME] == null, or  empty string) {
	serviceName = DEFAULT_SERVICE_NAME;	
} else {
	serviceName = Options[SERVICE_NAME];
}

// Create an appropriate ServiceController
ServiceController serviceController = new ServiceController(serviceName);

// Get timeout
int timeout;
if (Options[TIMEOUT] == null, or  empty string) {
	timeout = DEFAULT_TIMEOUT;
} else {
	timeout = Int32.Parse(Options[TIMEOUT]);
}

// Stop the service
if (serviceController.CanStop) {
	ServiceController.Stop();
} else {
	// throw ServerException here
}

// Wait for the service to reach the desired status, or the timeout expired
service.WaitForStatus(ServiceControllerStatus.Stopped, TimeSpan.ForMilliseconds(timeout));
// Note, that the TimeoutException should be caught and wrapped into the ServerException




