/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 1.0
 */

namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// This class is derived from <see cref="Server"/> class and is the base class for all classes representing an
    /// application server to be used while running tests.
    /// </summary>
    /// <remarks>
    /// <para>
    /// The supported options are:
    /// <list>
    /// <item>
    /// DEPLOYMENT_DIR - specifies the directory the application should be deployed to.
    /// </item>
    /// </list>
    /// </para>
    /// <para>
    /// This class is mutable, i.e. not thread-safe.
    /// </para>
    /// </remarks>
    public abstract class ApplicationServer : Server
    {
        /// <summary>
        /// This string constant represents the name (key) of the option, the derived classes should use for getting
        /// the directory the application should be deployed to.
        /// </summary>
        /// <remarks>
        /// Note that the derived classes can treat options in any way they like. The most simple way this option can
        /// be used is copying the files specified by the <see cref="Server.SourceFiles"/> property to the directory
        /// specified by this option.
        /// </remarks>
        public const string DEPLOYMENT_DIR = "deployment_dir";

        /// <summary>
        /// This property represents the value of the option that defines what directory the derived classes should
        /// deploy the application to.
        /// </summary>
        /// <remarks>
        /// Note that the derived classes can treat options in any way they like. The most simple way this option can
        /// be used is copying the files specified by the <see cref="Server.SourceFiles"/> property to the directory
        /// specified by this option.
        /// </remarks>
        /// <value>
        /// A string representing the deployment directory.
        /// </value>
        public string DeploymentDirectory
        {
            get
            {
                return GetOption(DEPLOYMENT_DIR);
            }
        }

        /// <summary>
        /// Constructor, called by subclass constructors.
        /// </summary>
        protected ApplicationServer()
            : base()
        {
        }
    }
}
